#!/bin/bash
# Default options
#
#
#
date
#### 1  Set up the compiling options
#### Define some directories
submitdir=$( pwd )
modipsl=$submitdir/../..
arch_path=$submitdir/ARCH 
mysrc_path=$submitdir/SOURCES
export ROOT=$modipsl/modeles/DYNAMICO
#### Set default options 
# Resolution if compiling LMDZ in regular mode without DYNAMICO
# Use for example following "./compile_icolmdzor.sh -regular_latlon 144x142x79"
regular_latlon=no
# Atmospheric resolution, for LMDZ/ORCHIDEE in regular mode
resol_atm=144x142x79
# Coupled with ocean biogeochemistry (y/n)
nemotop=y
# Optimization mode
# optmode=prod/dev/debug
optmode=prod
# Resolution if compiling LMDZ in regular mode without DYNAMICO
# Use for example following "./compile_icolmdzor.sh -regular_latlon 144x142x79"
regular_latlon=no
# fcm_arch
fcm_arch=default
# Default values to be overritten
parallel=mpi_omp
export fcm_arch parallel xios
full_flag=""
full_nemo=n
full_inca=""
full_xios=""
full_lmdz=""
full_orch=""
full_dyna=""
# choose radiative code compilation option 
rad=rrtm
opt_rad=""
#choose chemistry inca configuration 
optchimie=GES

# orchversion tells if ORCHIDEE_2_2 or ORCHIDEE_trunk is compiled. This is used as argument and also in the suffix of the executables.
# orchcomp is the key word needed for LMDZ for the compilation of coherent interface. Only used internal to the compilation script.
orchversion=orch22
orchcomp=orchidee2.1

# Default netcdf_lib is used for XIOS but can be change by argument
netcdf_lib=""

# Output text file for compilation of each component
datestr=`LC_ALL=C date +"%Y%m%dT%H%M"`
outfile=$submitdir/out_compile_ipslcm7.$datestr
echo > $outfile
echo; echo "Text output from compilation will be stored in file out_compile_ipslcm7.$datestr"; echo 


echo "create out_compile_ipslcm7 link "
rm -f out_compile_ipslcm7
ln -s ${outfile} out_compile_ipslcm7



#### Read arguments 
# Loop over all arguments to modify default set up
while (($# > 0)) ; do
    case $1 in
	"-h") cat <<end_help
########################################################################
# Usage of the script compile_ipslcm7.sh
#
########################################################################

./compile_ipslcm7.sh [Options] 


Options: [-full] Full recompilation of all components. This option can be added to all other options.
         [-cleannemo] Full recompilation of NEMO component only.
         [-regular_latlon]
         [-debug / -dev / -prod] Level of optimization. One of these can be added to all other compile options. Default: -prod.


Example 1: Default compilation of IPSLCM7 for resolution LR 
          (Resolution atmos: nbp40 )
./compile_ipslcm7.sh

Example 2: Default resolution (LR) compiled in debug mode
./compile_ipslcm7.sh -debug

Example 3: Default compilation with full recompilation of all components. No clean is needed.
./compile_ipslcm7.sh -full

Example 4: Compilation of LMDZ in regular lat-lon for dimension 144x142x79. 
           The dimension can be changed to any other 3d dimension. DYNAMICO is also compiled as default.
./compile_ipslcm7.sh -regular_latlon 144x142x79

Example 5: Compiltion of ORCHIDEE_trunk version
           Note that for compiling ORCHIDEE trunk you must first have extracted ORCHIDEE_trunk folder in modeles. 
           modeles/ORCHIDEE_2_2 folder can be kept at the same time.
./compile_ipslcm7.sh -orch4
./compile_ipslcm7.sh -regular_latlon 144x142x79 -orch4


Example 6: compilation of a specific chemistry for INCA (default is GES) 
./compile_ipslcm7.sh -chimie NMHC_AER_S 

end_help
	    exit;;

	"-parallel")   parallel=$2 ; shift ; shift ;; 
	"-arch")       fcm_arch="$2" ; shift ; shift ;;
	"-debug")      optmode=debug ; shift ;;
	"-dev")	       optmode=dev ; shift ;;
	"-prod")       optmode=prod ; shift ;;
	"-regular_latlon")  regular_latlon=yes ; resol_atm=$2 ; shift ; shift ;;
	"-full")       full_flag="-full"; full_nemo=y ; full_xios="--full" ; full_lmdz="-full" ; full_orch="-full" ; shift ;;
	"-full_xios")  full_xios="--full" ; shift ;;  # Note only full_xios is using double dash: --full
	"-full_lmdz")  full_lmdz="-full"  ; shift ;;
	"-full_orch")  full_orch="-full"  ; shift ;;
	"-full_nemo")  full_nemo=y ; shift ;;
	"-full_inca")  full_inca="-clean"; shift ;;
	"-full_dyna")  full_dyna="-full" ; shift ;; 	
	"-cleannemo")  full_nemo=y ; shift ;;
	"-rad")        rad=$2; shift ; shift ;;
	"-orch22")     orchversion="orch22"; orchcomp=orchidee2.1; shift ;;
	"-orch4")      orchversion="orch4"; orchcomp=orchideetrunk; shift ;;
	"-chimie")     optchimie=$2; shift ; shift;;
	*)	       echo "unknown option "$1" , exiting..." ; exit
    esac
done

echo "Following options are set in current compiling:" >> $outfile
echo "   regular_latlon=$regular_latlon (if yes, then resol_atm=${resol_atm})" >> $outfile 
echo "   resol_atm=${resol_atm}, resol_oce=${resol_oce}, icemodel=${icemodel}, nemotop=${nemotop}" >> $outfile 
echo "   optmode = $optmode, parallel = $parallel, fcm_arch = $fcm_arch " >> $outfile 
echo "   full_flag=$full_flag, full_xios=$full_xios, full_lmdz=$full_lmdz, full_orch=$full_orch, full_nemo=$full_nemo, full_dyna=$full_dyna" >> $outfile 
echo >> $outfile

### Read host dependent default values
### These variables will not be changed if they were set as argument
###./host.sh $host
# Later : Following lines should be set in host.sh file
# begin host.sh
if [ $fcm_arch == default ] ; then
    # Find out current host and source specific paths and commands for the host
    case $( hostname -s ) in
	jean-zay*)
	    fcm_arch=X64_JEANZAY;;
        irene170|irene171|irene190|irene191|irene192|irene193)
            fcm_arch=X64_IRENE;;
        irene172|irene173|irene194|irene195)
            fcm_arch=X64_IRENE-AMD;;
	asterix*|obelix*)
	    fcm_arch=ifort_LSCE
            if [ "${parallel}" == "mpi_omp" ] ; then 
		echo "Warning!! Currently at Obelix hybrid mode is not possible."
		echo "          Option -parallel mpi_omp is now changed to -parallel mpi"
		echo ""
		parallel=mpi
            else
		echo "You used -parallel" $parallel
            fi ;;
        spirit*)
            fcm_arch=ifort_MESOIPSL;;
	ciclad*|climserv*|loholt*|camelot*)
	    fcm_arch=ifort_CICLAD;;
	*)
	    echo Current host is not known. You must use option -arch to specify which architecuture files to use.
	    echo Exit now.
	    exit
    esac
fi

# Set a link to arch.env if arch-${fcm_arch}.env file exist for current fcm_arch.
# The link arch.env is also set in config.card and will be used by libIGCM to ensure the same running environnement.
if [ -f ARCH/arch-${fcm_arch}.env ] ; then
    echo >> $outfile
    echo "The file ARCH/arch-${fcm_arch}.env will now be sourced with modules needed for compilation for all components."
    echo "Note that this new environement might be kept after compilation."
    echo "If this is the case, source again your personal environment after compilation."
    echo " Personal module list before sourcing of ARCH/arch.env file:"    >> $outfile 
    module list   >> $outfile 2>&1
    svn_version=$(module list -t | grep subversion)
       
    # Make a link to this file, to be used also in config.card
    rm -f ARCH/arch.env
    ln -s arch-${fcm_arch}.env ARCH/arch.env

    # Source the file
    source ARCH/arch.env   >> $outfile 2>&1
    if [ X$svn_version != X ] ; then
	module load ${svn_version}
    fi
    echo >> $outfile
    echo " New module list after sourcing of ARCH/arch.env file:"    >> $outfile 
    module list   >> $outfile 2>&1
fi


#### Clean if full_orch
# If full recompilation of ORCHIDEE then first clean modipsl/lib folder
if [ X${full_orch} == X"-full" ] ; then
   rm -f $modipsl/lib/*
fi

#### 2 Do the compilation 
## 2.1 Compile ioipsl
cd $modipsl/modeles/IOIPSL
echo; echo "NOW COMPILE IOIPSL"
echo >> $outfile ; echo " NOW COMPILE IOIPSL"   >> $outfile 

echo ./makeioipsl_fcm -$optmode -parallel -arch ${fcm_arch} -arch_path $arch_path -j 8 $full_flag   >> $outfile 
     ./makeioipsl_fcm -$optmode -parallel -arch ${fcm_arch} -arch_path $arch_path -j 8 $full_flag   >> $outfile 2>&1
# Test if compiling succeded 
if [[ $? != 0 ]] ; then 
    echo "THERE IS A PROBLEM IN IOIPSL COMPILATION - STOP"
    exit
fi

## 2.2 Compile oasis3-mct
cd $modipsl/oasis3-mct/util/make_dir
echo; echo "NOW COMPILE OASIS3-MCT"
echo >> $outfile ; echo " NOW COMPILE OASIS3-MCT"   >> $outfile
cp $mysrc_path/OASIS3-MCT/make_${fcm_arch} make.inc

echo make -f TopMakefileOasis3 >> $outfile
     make -f TopMakefileOasis3 >> $outfile 2>&1


## 2.3 Compile xios
cd $modipsl/modeles/XIOS
echo; echo "NOW COMPILE XIOS"
echo >> $outfile ; echo " NOW COMPILE XIOS"   >> $outfile 
echo ./make_xios --use_oasis oasis3_mct --$optmode --arch $fcm_arch --arch_path $arch_path ${netcdf_lib} --job 4 $full_xios   >> $outfile 
     ./make_xios --use_oasis oasis3_mct --$optmode --arch $fcm_arch --arch_path $arch_path ${netcdf_lib} --job 4 $full_xios   >> $outfile 2>&1
# Test if compiling succeded 
if [[ $? != 0 ]] ; then 
    echo "THERE IS A PROBLEM IN XIOS COMPILATION - STOP"
    exit
fi
# Move executables to modipsl/bin
if [ -f $modipsl/modeles/XIOS/bin/xios_server.exe ] ; then 
    mv $modipsl/modeles/XIOS/bin/xios_server.exe $modipsl/bin/xios_server_${optmode}.exe
else
    echo "THERE IS A PROBLEM IN XIOS COMPILATION EXECUTABLE MISSING - STOP"
    exit
fi


## 2.4 Compile ORCHIDEE
# Choose ORCHIDEE version to compile and create a link to generic folder name ORCHIDEE.
# This link is needed for the compilation of ICOSA_LMDZ for it to find the orchidee librarie. 
cd $modipsl/modeles
rm -f ORCHIDEE
if [ $orchversion == orch22 ] ; then
    ln -s ORCHIDEE_2_2 ORCHIDEE
    cd $modipsl/modeles/ORCHIDEE_2_2
    echo; echo "NOW COMPILE ORCHIDEE_2_2"
    echo >> $outfile ; echo " NOW COMPILE ORCHIDEE_2_2"   >> $outfile 
else
    ln -s ORCHIDEE_trunk ORCHIDEE
    cd $modipsl/modeles/ORCHIDEE_trunk
    echo; echo "NOW COMPILE ORCHIDEE_trunk v4"
    echo >> $outfile ; echo " NOW COMPILE ORCHIDEE_trunk v4"   >> $outfile 
fi

# Check if the compilation of ORCHIDEE was previsouly interupted prematured. 
# In that case, the files fcm.bld.lock exist. If the file exist, it is here removed to avoid makeorchidee_fcm 
# to ask question and wait for interactivly answer from the user.
if [ -f build/fcm.bld.lock ] ; then
    echo >> $outfile
    echo " WARNING!! The file ORCHIDEE/build/fcm.bld.lock exist. "   >> $outfile
    echo "           This means that the compilation is either currently on going in another terminal was previous interupted before the end."   >> $outfile
    echo "           The file will now be removed. "   >> $outfile
    echo >> $outfile
    rm -f build/fcm.bld.lock
fi

echo    ./makeorchidee_fcm -j 8 -xios -parallel $parallel -$optmode -arch ${fcm_arch} -arch_path $arch_path $full_orch  >> $outfile 
        ./makeorchidee_fcm -j 8 -xios -parallel $parallel -$optmode -arch ${fcm_arch} -arch_path $arch_path $full_orch  >> $outfile 2>&1
# Test if compiling finished
if [[ $? != 0 ]] ; then
    echo "THERE IS A PROBLEM IN ORCHIDEE COMPILATION - STOP"
    exit
fi

# Rename exetubles for ORCHIDEE offline driver with suffix version
cd $modipsl/bin
if [ -f orchideedriver ] ; then mv orchideedriver orchideedriver.$orchversion ; fi
if [ -f orchidee_ol ] ; then mv orchidee_ol orchidee_ol.$orchversion ; fi


## 2.5 Compile NEMO
nemo_root=$modipsl/modeles/NEMO
cfg_ref=ORCA2_ICE_PISCES
cfg_wrk=ORCA_ICE_TRC
addkeys="key_oasis3 key_top key_si3 key_isf"
delkeys=""

if [ ${nemotop} == n ] ; then
   cfg_wrk=ORCA_ICE
   delkeys="key_top"
fi

if [ ${nemotop} == n ] ; then
   echo; echo "NOW COMPILE NEMO with ice model SI3 without passive tracer model TOP"
   echo >> $outfile ; echo " NOW COMPILE NEMO with ice model SI3 without passive tracer model TOP"   >> $outfile
else
   echo; echo "NOW COMPILE NEMO with ice model SI3 and passive tracer model TOP"
   echo >> $outfile ; echo " NOW COMPILE NEMO with ice model SI3 and passive tracer model TOP"   >> $outfile
fi

echo >> $outfile ; echo cd $nemo_root  >> $outfile
echo >> $outfile ; echo cp $mysrc_path/NEMO/arch-${fcm_arch}.fcm arch/CNRS/.   >> $outfile
echo >> $outfile

cd $nemo_root ; cp $mysrc_path/NEMO/arch-${fcm_arch}.fcm arch/CNRS/.

# creation of config
echo >> $outfile ; echo cd $nemo_root  >> $outfile
echo ./makenemo -m ${fcm_arch} -n $cfg_wrk -r $cfg_ref -j0 add_key "$addkeys"  del_key "$delkeys"   >> $outfile
echo >> $outfile
cd $nemo_root
./makenemo -m ${fcm_arch} -n $cfg_wrk -r $cfg_ref -j0  add_key "$addkeys"  del_key "$delkeys"  >> $outfile 2>&1


# Copy of specfic source files
echo >> $outfile ; echo cp $mysrc_path/NEMO/*.*90  $nemo_root/cfgs/$cfg_wrk/MY_SRC/.   >> $outfile
echo >> $outfile
cp $mysrc_path/NEMO/*.*90  $nemo_root/cfgs/$cfg_wrk/MY_SRC/.


if [ $full_nemo == y ] ; then
   # To make a full compilation, first make a clean to remove all files produced during previous compilation
   echo ./makenemo -m ${fcm_arch} -n $cfg_wrk -r $cfg_ref clean   >> $outfile
   echo >> $outfile
   ./makenemo -m ${fcm_arch} -n $cfg_wrk -r $cfg_ref clean  >> $outfile 2>&1
fi
echo ./makenemo -m ${fcm_arch} -n $cfg_wrk -r $cfg_ref -j8  >> $outfile
echo >> $outfile
./makenemo -m ${fcm_arch} -n $cfg_wrk -r $cfg_ref -j8  >> $outfile 2>&1

echo >> $outfile
echo "Move nemo executable to modipsl/bin" >> $outfile
echo ls -lrt $nemo_root/cfgs/$cfg_wrk/BLD/bin   >> $outfile
ls -lrt $nemo_root/cfgs/$cfg_wrk/BLD/bin  >> $outfile
echo >> $outfile

if [ -f $nemo_root/cfgs/$cfg_wrk/BLD/bin/nemo.exe ] ; then
   mv $nemo_root/cfgs/$cfg_wrk/BLD/bin/nemo.exe $modipsl/bin/opa_${optmode}.exe
else
    echo "ERROR nemo.exe executable does not exist."
    echo "THERE IS A PROBLEM IN NEMO COMPILATION - STOP"
    exit
fi


##2.6  Compile INCA 
    cd $modipsl/modeles/INCA

    echo; echo "NOW COMPILE INCA ${optchimie}"
    echo ./makeinca_fcm -chimie ${optchimie} -$optmode -xios -parallel mpi_omp -j 8 -arch ${fcm_arch}  -arch_path $arch_path $full_flag  >> $outfile
    ./makeinca_fcm -chimie ${optchimie} -$optmode -xios -parallel mpi_omp  -j 8 -arch ${fcm_arch} -arch_path $arch_path  $full_flag >> $outfile 2>&1

    # Test if compiling finished
    if [[ $? != 0 ]] ; then
	echo "THERE IS A PROBLEM IN INCA COMPILATION - STOP"
	echo "ALL INFORMATION IN FILE $outfile"
	exit
    fi

    echo "Move inca.dat modipsl/bin"
    if [[ -f $modipsl/modeles/INCA/SIMULATIONS/${optchimie}/inca.dat ]] ;  then  
	mv $modipsl/modeles/INCA/SIMULATIONS/${optchimie}/inca.dat $modipsl/bin/inca_${optchimie}.dat ;
    else
	echo "THERE IS A PROBLEM IN INCA COMPILATION - STOP"
	echo "ALL INFORMATION IN FILE $outfile"
	exit	
    fi

    echo "Move tracer.def to  modipsl/bin"
    if [[ -f $modipsl/modeles/INCA/tracer.def ]] ;  then
        mv $modipsl/modeles/INCA/tracer.def $modipsl/bin/tracer_${optchimie}.def ;
    fi



## 2.7 Compile LMDZ 
cd $modipsl/modeles/LMDZ
# Compile LMDZ as library to couple to DYNAMICO
echo; echo "NOW COMPILE LMDZ FOR COUPLING TO DYNAMICO"
echo >> $outfile ; echo " NOW COMPILE LMDZ FOR COUPLING TO DYNAMICO"   >> $outfile 

# Retrieve the final svn release number, needed for radiative code suffix of executable
lmdzsvn=`svnversion . | egrep -o "[0-9]+"  | awk 'NR==1'`
# Temporary use of SOURCES/LMDZ to handle modifications needed by IPSLCM7
cp $mysrc_path/LMDZ/*.*90  libf/phylmd/.

# Check if the compilation of LMDZ was previsouly interupted prematured. 
# In that case, the files dimension.h and .lock exist. If the files exist, they are here removed to avoid makelmdz_fcm 
# to ask question and wait for interactivly answer from the user.
if [ -f libf/grid/dimensions.h ] || [ -f .lock ] ; then
  echo >> $outfile
  echo " WARNING!! The file LMDZ/libf/grid/dimension.h and/or the LMDZ/.lock exist. "   >> $outfile
  echo "           This means that the compilation is either currently on going in another terminal was previous interupted before the end."   >> $outfile
  echo "           The files dimension.h and .lock will now be removed. "   >> $outfile
  echo >> $outfile
  rm -f libf/grid/dimensions.h
  rm -f .lock
fi

# Need to define the proper option for radiative code compilation. By default, we use rrtm
case $rad in
    oldrad) opt_rad="" ;;
    rrtm)   if [ $lmdzsvn -le 4185 ] ; then opt_rad="-rrtm true" ; else opt_rad="-rad rrtm" ; fi ;;
    ecrad)  opt_rad="-rad ecrad" ;;
    *) echo Only oldrad rrtm ecrad for rad option ; exit
esac

if [ $lmdzsvn -le 4185 -a $rad = "ecrad" ] ; then echo "ecrad only available for LMDZ rev starting with 4186 " ; exit ; fi

echo ./makelmdz_fcm -p lmd -c OMCT $opt_rad -$optmode -mem -parallel $parallel -libphy -v $orchcomp -chimie INCA  -io xios -arch $fcm_arch -arch_path $arch_path -j 8 $full_lmdz    >> $outfile 
     ./makelmdz_fcm -p lmd -c OMCT $opt_rad -$optmode -mem -parallel $parallel -libphy -v $orchcomp -chimie INCA  -io xios -arch $fcm_arch -arch_path $arch_path -j 8 $full_lmdz    >> $outfile 2>&1
# Test if compiling finished
if [[ $? != 0 ]] ; then
    echo "THERE IS A PROBLEM IN LMDZ PHYSICS COMPILATION - STOP"
    exit
fi


## 2.8 Compile DYNAMICO
cd $modipsl/modeles/DYNAMICO
echo; echo "NOW COMPILE DYNAMICO "
echo >> $outfile ; echo " NOW COMPILE DYNAMICO"   >> $outfile 

echo ./make_icosa -$optmode -with_fcm1 -parallel $parallel -external_ioipsl -with_oasis -with_xios -arch $fcm_arch -arch_path $arch_path -job 8 $full_dyna    >> $outfile 
     ./make_icosa -$optmode -with_fcm1 -parallel $parallel -external_ioipsl -with_oasis -with_xios -arch $fcm_arch -arch_path $arch_path -job 8 $full_dyna    >> $outfile 2>&1
# Test if compiling finished
if [[ $? != 0 ]] ; then
    echo "THERE IS A PROBLEM IN DYNAMICO COMPILATION - STOP"
    exit
fi


## 2.9 Compile interface ICOSA_LMDZ
cd $modipsl/modeles/ICOSA_LMDZ
echo; echo "NOW COMPILE ICOSA_LMDZ "
echo >> $outfile ; echo " NOW COMPILE ICOSA_LMDZ"   >> $outfile 

echo ./make_icosa_lmdz -nodeps -p lmd -$optmode -parallel $parallel -with_oasis -with_orchidee -with_inca -arch ${fcm_arch} -arch_path ${arch_path} -job 8 $full_dyna    >> $outfile 
     ./make_icosa_lmdz -nodeps -p lmd -$optmode -parallel $parallel -with_oasis -with_orchidee -with_inca -arch ${fcm_arch} -arch_path ${arch_path} -job 8 $full_dyna    >> $outfile 2>&1
# Test if compiling finished
if [[ $? != 0 ]] ; then
    echo "THERE IS A PROBLEM IN ICOSA_LMDZ COMPILATION - STOP"
    exit
fi
# Move executables to modipsl/bin
if [ -f $modipsl/modeles/ICOSA_LMDZ/bin/icosa_lmdz.exe ] ; then 
    mv $modipsl/modeles/ICOSA_LMDZ/bin/icosa_lmdz.exe $modipsl/bin/icosa_lmdz_${orchversion}_${optmode}_${optchimie}.exe
    #create link to be use by IPSLCM and LMDZOR without any change in the executable name
    cd  $modipsl/bin
    rm -f icosa_lmdz_${orchversion}_${optmode}.exe
    ln -s icosa_lmdz_${orchversion}_${optmode}_${optchimie}.exe icosa_lmdz_${orchversion}_${optmode}.exe
else
    echo "THERE IS A PROBLEM IN ICOSA_LMDZ COMPILATION EXECUTABLE MISSING - STOP"
    exit
fi



## 2.10 Compile LMDZ for regular latlon configuration
if [ $regular_latlon = yes ] ; then

    cd $modipsl/modeles/LMDZ
    # Compile LMDZ regular lat-lon exectuable
    echo; echo "NOW COMPILE LMDZ REGULAR LAT-LON MODE. Resolution = ${resol_atm}"
    echo >> $outfile ; echo " NOW COMPILE LMDZ REGULAR LAT-LON MODE. Resolution = ${resol_atm}"   >> $outfile 
    # Check if the compilation of LMDZ was previsouly interupted prematured. 
    # In that case, the files dimension.h and .lock exist. If the files exist, they are here removed to avoid makelmdz_fcm 
    # to ask question and wait for interactivly answer from the user.
    if [ -f libf/grid/dimensions.h ] || [ -f .lock ] ; then
	echo >> $outfile
	echo " WARNING!! The file LMDZ/libf/grid/dimension.h and/or the LMDZ/.lock exist. "   >> $outfile
	echo "           This means that the compilation is either currently on going in another terminal was previous interupted before the end."   >> $outfile
	echo "           The files dimension.h and .lock will now be removed. "   >> $outfile
	echo >> $outfile
	rm -f libf/grid/dimensions.h
	rm -f .lock
    fi
    echo ./makelmdz_fcm -d ${resol_atm} -c OMCT -p lmd $opt_rad -$optmode -mem -parallel $parallel -chimie INCA  -io xios -v $orchcomp -arch $fcm_arch -arch_path $arch_path -j 8 $full_lmdz gcm    >> $outfile 
         ./makelmdz_fcm -d ${resol_atm} -c OMCT -p lmd $opt_rad -$optmode -mem -parallel $parallel -chimie INCA  -io xios -v $orchcomp -arch $fcm_arch -arch_path $arch_path -j 8 $full_lmdz gcm    >> $outfile 2>&1
    # Test if compiling finished
    if [[ $? != 0 ]] ; then
	echo "THERE IS A PROBLEM IN LMDZ REGULAR LATLON COMPILATION - STOP"
	exit
    fi

    # Find executable suffix
    suffix=_${resol_atm}_phylmd
    if [ $lmdzsvn -ge 4186 ] ; then suffix=${suffix}_${rad} ; fi
    if [ $parallel == seq ] || [ $parallel == none ] ; then
	suffix=${suffix}_seq_orch_inca.e
    else
	suffix=${suffix}_para_mem_orch_couple_inca.e
    fi
    echo gcm suffix = $suffix
    
    # Move executables to modipsl/bin folder
    echo "Move gcm.e executable to modipsl/bin"
    if [ -f $modipsl/modeles/LMDZ/bin/gcm${suffix} ] ;  then
	mv $modipsl/modeles/LMDZ/bin/gcm${suffix} $modipsl/bin/gcm_${resol_atm}_${orchversion}_${optmode}_${optchimie}.e
	#create link to be use by IPSLCM and LMDZOR without any change in the executable name
	cd $modipsl/bin
	rm -f gcm_${resol_atm}_${orchversion}_${optmode}.e
	ln -s gcm_${resol_atm}_${orchversion}_${optmode}_${optchimie}.e gcm_${resol_atm}_${orchversion}_${optmode}.e
    else
	echo "ERROR gcm${suffix} executable does not exist." 
	echo "THERE IS A PROBLEM IN LMDZ REGULAR LATLON COMPILATION - STOP"
	exit
    fi    

    # Compile ce0l initialization program for LMDZ regular lat-lon exectuable
    cd $modipsl/modeles/LMDZ
    echo; echo "NOW COMPILE CE0L OF LMDZ. Resolution = ${resol_atm}"
    echo >> $outfile ; echo " NOW COMPILE CE0L OF LMDZ. Resolution = ${resol_atm}"   >> $outfile 

    echo ./makelmdz_fcm -d ${resol_atm} -c OMCT -p lmd -rrtm true -$optmode -mem -parallel $parallel -io xios -v $orchcomp -arch $fcm_arch -arch_path $arch_path -j 8 $full_lmdz ce0l    >> $outfile 
         ./makelmdz_fcm -d ${resol_atm} -c OMCT -p lmd -rrtm true -$optmode -mem -parallel $parallel -io xios -v $orchcomp -arch $fcm_arch -arch_path $arch_path -j 8 $full_lmdz ce0l    >> $outfile 2>&1
    # Test if compiling finished
    if [[ $? != 0 ]] ; then
	echo "THERE IS A PROBLEM IN CE0L (LMDZ) REGULAR LATLON COMPILATION - STOP"
	exit
    fi
   
 
    # Move executable ce0l to modipsl/bin folder
    echo "Move ce0l executable to modipsl/bin"
    if [ -f $modipsl/modeles/LMDZ/bin/ce0l${suffix} ] ;  then
	mv $modipsl/modeles/LMDZ/bin/ce0l${suffix} $modipsl/bin/ce0l_${resol_atm}_${optmode}.e
    else
	echo "ERROR ce0l${suffix} executable does not exist." 
	echo "THERE IS A PROBLEM IN LMDZ REGULAR LATLON COMPILATION - STOP"
	exit
    fi
fi

echo >>$outfile ; echo "ALL COMPILING FINISHED" >> $outfile
echo ls -lrt modipsl/bin >> $outfile
ls -lrt $modipsl/bin >> $outfile

echo; echo "ALL COMPILING FINISHED" ; echo
echo "Executables are found in modipsl/bin"
echo "Check that executable names correspond with the name set in config.card before launching the job"
echo ls -lrt modipsl/bin
ls -lrt $modipsl/bin

date

exit


